You are viewing a plain text version of this content. The canonical link for it is here.
Posted to fop-commits@xmlgraphics.apache.org by sp...@apache.org on 2005/12/09 13:46:36 UTC

svn commit: r355471 - in /xmlgraphics/fop/trunk/src/java/org/apache/fop: Version.java apps/FOPException.java apps/Fop.java fo/FONode.java

Author: spepping
Date: Fri Dec  9 04:46:23 2005
New Revision: 355471

URL: http://svn.apache.org/viewcvs?rev=355471&view=rev
Log:
The result of some practice with Checkstyle

Modified:
    xmlgraphics/fop/trunk/src/java/org/apache/fop/Version.java
    xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/FOPException.java
    xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/Fop.java
    xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/FONode.java

Modified: xmlgraphics/fop/trunk/src/java/org/apache/fop/Version.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/fop/trunk/src/java/org/apache/fop/Version.java?rev=355471&r1=355470&r2=355471&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/src/java/org/apache/fop/Version.java (original)
+++ xmlgraphics/fop/trunk/src/java/org/apache/fop/Version.java Fri Dec  9 04:46:23 2005
@@ -23,7 +23,9 @@
  * Note that this class can only find the version information if it's in the org.apache.fop package
  * as this package equals the one specified in the manifest.
  */
-public class Version {
+public final class Version {
+    
+    private Version() { }
 
     /**
      * Get the version of FOP

Modified: xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/FOPException.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/FOPException.java?rev=355471&r1=355470&r2=355471&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/FOPException.java (original)
+++ xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/FOPException.java Fri Dec  9 04:46:23 2005
@@ -43,7 +43,8 @@
     /**
      * Constructs a new FOP exception with the specified detail message and location.
      * @param message the detail message
-     * @param systemId the system id of the FO document which is associated with the exception. May be null.
+     * @param systemId the system id of the FO document which is associated with the exception
+     *                 may be null.
      * @param line line number in the FO document which is associated with the exception.
      * @param column clolumn number in the line which is associated with the exception.
      */
@@ -96,7 +97,8 @@
 
     /**
      * Set a location associated with the exception.
-     * @param systemId the system id of the FO document which is associated with the exception. May be null.
+     * @param systemId the system id of the FO document which is associated with the exception;
+     *                 may be null.
      * @param line line number in the FO document which is associated with the exception.
      * @param column clolumn number in the line which is associated with the exception.
      */
@@ -108,6 +110,7 @@
 
     /**
      * Indicate whether a location was set.
+     * @return whether a location was set
      */
     public boolean isLocationSet() {
         // TODO: this is actually a dangerous assumption: A line
@@ -124,6 +127,7 @@
      *  SystemId:LL:CC: &the message&
      * </pre>
      * (the format used by most GNU tools)
+     * @return the detail message string of this FOP exception
      */
     public String getMessage() {
         if (isLocationSet()) {

Modified: xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/Fop.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/Fop.java?rev=355471&r1=355470&r2=355471&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/Fop.java (original)
+++ xmlgraphics/fop/trunk/src/java/org/apache/fop/apps/Fop.java Fri Dec  9 04:46:23 2005
@@ -67,7 +67,6 @@
      * output format (ex. "application/pdf" for PDF).
      * @param outputFormat the MIME type of the output format to use (ex. "application/pdf").
      * @param ua FOUserAgent object
-     * @throws IllegalArgumentException if an unsupported renderer type was requested.
      */
     public Fop(String outputFormat, FOUserAgent ua) {
         this.outputFormat = outputFormat;
@@ -82,7 +81,6 @@
      * Constructor for FOP with a default FOUserAgent. It uses MIME types to select the 
      * output format (ex. "application/pdf" for PDF).
      * @param outputFormat the MIME type of the output format to use (ex. "application/pdf").
-     * @throws IllegalArgumentException if an unsupported renderer type was requested.
      */
     public Fop(String outputFormat) {
         this(outputFormat, null);
@@ -106,7 +104,6 @@
      * <li>Fop.RENDER_PNG</li>
      * </ul>
      * @param ua FOUserAgent object
-     * @throws IllegalArgumentException if an unsupported renderer type was requested.
      * @deprecated Use {@link org.apache.fop.apps.Fop#Fop(java.lang.String, FOUserAgent)} instead!
      *             This constructor will be removed.
      */

Modified: xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/FONode.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/FONode.java?rev=355471&r1=355470&r2=355471&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/FONode.java (original)
+++ xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/FONode.java Fri Dec  9 04:46:23 2005
@@ -70,16 +70,16 @@
     /**
      * Perform a shallow cloning operation,
      * set its parent, and optionally clean the list of child nodes
      * @param parent the intended parent of the clone
      * @param removeChildren if true, clean the list of child nodes
      * @return the cloned FO node
      * @throws FOPException if there's a problem while cloning the node
      */
-    public FONode clone(FONode parent, boolean removeChildren)
+    public FONode clone(FONode cloneparent, boolean removeChildren)
                 throws FOPException {
         FONode foNode = (FONode) clone();
-        foNode.parent = parent;
-        parent.addChildNode(foNode);
+        foNode.parent = cloneparent;
+        cloneparent.addChildNode(foNode);
         return foNode;
     }
 
@@ -146,11 +146,11 @@
      * @param elementName element name (e.g., "fo:block")
      * @param locator Locator object (ignored by default)
      * @param attlist Collection of attributes passed to us from the parser.
      * @param parent the property list of the parent node
      * @throws FOPException for errors or inconsistencies in the attributes
     */
     public void processNode(String elementName, Locator locator, 
-            Attributes attlist, PropertyList parent) throws FOPException {
+            Attributes attlist, PropertyList pList) throws FOPException {
         if (log.isDebugEnabled()) {
             log.debug("Unhandled element: " + elementName 
                     + (locator != null ? " at " + getLocatorString(locator) : ""));
@@ -160,13 +160,13 @@
     /**
      * Create a property list for this node. Return null if the node does not
      * need a property list.
      * @param parent the closest parent propertylist. 
      * @param foEventHandler The FOEventHandler where the PropertyListMaker 
      *              instance can be found.
      * @return A new property list.
      * @throws FOPException if there's a problem during processing
      */
-    protected PropertyList createPropertyList(PropertyList parent, FOEventHandler foEventHandler) 
+    protected PropertyList createPropertyList(PropertyList pList, FOEventHandler foEventHandler) 
                 throws FOPException {
         return null;
     }



---------------------------------------------------------------------
@@ -70,16 +70,16 @@
      * Perform a shallow cloning operation,
      * set its parent, and optionally clean the list of child nodes
-     * @param parent the intended parent of the clone
+     * @param cloneparent the intended parent of the clone
      * @param removeChildren if true, clean the list of child nodes
      * @return the cloned FO node
@@ -146,11 +146,11 @@
      * @param locator Locator object (ignored by default)
      * @param attlist Collection of attributes passed to us from the parser.
-     * @param parent the property list of the parent node
+     * @param pList the property list of the parent node
      * @throws FOPException for errors or inconsistencies in the attributes
     */
@@ -160,13 +160,13 @@
      * Create a property list for this node. Return null if the node does not
      * need a property list.
-     * @param parent the closest parent propertylist. 
+     * @param pList the closest parent propertylist. 
      * @param foEventHandler The FOEventHandler where the PropertyListMaker 
      *              instance can be found.
To unsubscribe, e-mail: fop-commits-unsubscribe@xmlgraphics.apache.org
For additional commands, e-mail: fop-commits-help@xmlgraphics.apache.org